/*
** pork_buddy.h - Buddy list / permit / deny management.
** Copyright (C) 2002-2003 Ryan McCabe <ryan@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
*/

#ifndef __PORK_BUDDY_H
#define __PORK_BUDDY_H

#define STATUS_OFFLINE	0
#define STATUS_ACTIVE	1
#define STATUS_IDLE		2
#define STATUS_AWAY		3

#define USER_TYPE_AOL			0x01
#define USER_TYPE_AIM			0x02
#define USER_TYPE_UNCONFIRMED	0x04
#define USER_TYPE_WIRELESS		0x08
#define USER_TYPE_ADMIN			0x10
#define USER_TYPE_ACTIVEBUDDY	0x20

struct aim_priv;

struct buddy_pref {
	dlist_t *group_list;
	dlist_t *permit_list;
	dlist_t *block_list;
	u_int32_t next_group_refnum;
	u_int16_t privacy_mode;
	u_int16_t report_idle;
	hash_t buddy_hash;
};

struct bgroup {
	char *name;
	u_int32_t refnum;
	u_int32_t num_online;
	u_int32_t num_members;
	u_int32_t high_refnum;
	dlist_t *member_list;
	dlist_t *blist_line;
};

struct buddy {
	char *name;
	char *nname;
	struct bgroup *group;
	u_int32_t refnum;
	u_int32_t signon_time;
	u_int32_t idle_time;
	u_int32_t warn_level;
	u_int32_t status:2;
	u_int32_t notify:1;
	u_int32_t ignore:1;
	u_int32_t type:6;
	u_int32_t last_seen;
	dlist_t *blist_line;
};

void buddy_update(	struct aim_priv *priv,
					struct buddy *buddy,
					aim_userinfo_t *userinfo);

void buddy_online(	struct aim_priv *priv,
					struct buddy *buddy,
					aim_userinfo_t *userinfo);

void buddy_offline(struct aim_priv *priv, struct buddy *buddy);
void buddy_offline_all(struct aim_priv *priv);

void buddy_alias(struct aim_priv *p, struct buddy *buddy, char *alias, int aim);

struct bgroup *group_find(struct aim_priv *priv, char *group_name);
struct buddy *buddy_find(struct aim_priv *priv, const char *screen_name);

void buddy_update_idle(struct aim_priv *priv);

struct buddy *buddy_add(struct aim_priv *priv,
						const char *screen_name,
						struct bgroup *group,
						int aim);

int buddy_init(struct aim_priv *priv);
void buddy_destroy(struct aim_priv *priv);

struct bgroup *group_add(struct aim_priv *priv, char *group_name);
int group_remove(struct aim_priv *priv, char *group_name, int aim);
int buddy_remove(struct aim_priv *priv, const char *screen_name, int aim);
int buddy_add_block(struct aim_priv *priv, char *screen_name, int aim);
int buddy_remove_block(struct aim_priv *priv, char *screen_name, int aim);
int buddy_add_permit(struct aim_priv *priv, char *screen_name, int aim);
int buddy_remove_permit(struct aim_priv *priv, char *screen_name, int aim);

void buddy_clear_block(struct aim_priv *priv);
void buddy_clear_permit(struct aim_priv *priv);

#endif
